==> nobone-sync-0.5.4.tgz: package/main.js <==
var app, cmder, conf, err, file, kit, port, remote;

kit = require('nokit');

kit.require('colors');

cmder = require('commander');

cmder.option('-h, --help', 'Help', function() {
  return cmder.help();
});

cmder.option('-s, --server');

cmder.option('-u, --upload <localFile host[:port]/path/to/dir>', 'Upload file or directory to remote host.');

cmder.option('-p, --password <pwd>', 'Password.');

cmder.option('-a, --algorithm <alg>', 'Algorithm', 'aes128');

cmder.option('-v, --ver');

cmder.parse(process.argv);

if (cmder.version) {
  console.log((require('./package.json')).version);
  process.exit();
}

if (cmder.upload) {
  if (cmder.args.length === 1) {
    conf = {};
    file = cmder.upload;
    file && (conf.localDir = file);
    remote = /([^\/:]+)(:\d+)?\/(.*)/.exec(cmder.args[0]);
    if (!remote || !remote[3]) {
      kit.err('Wrong argument, host[:port]/path/to/file wanted.');
      process.exit(1);
    }
    conf.host = remote[1] || '';
    port = remote[2] || ':8345';
    conf.port = port.slice(1);
    conf.remoteDir = "/" + remote[3];
    conf.password = cmder.password;
    conf.algorithm = cmder.algorithm;
    require('./client')(conf, false);
  } else if (cmder.args.length !== 0) {
    kit.err("Wrong args number, 2 wanted");
  }
} else {
  try {
    require('coffee-script/register');
    conf = require(kit.path.resolve(cmder.args[1] || cmder.args[0]));
  } catch (_error) {
    err = _error;
    if (cmder.args.length > 0) {
      kit.err(err.stack);
      process.exit(1);
    } else {
      kit.log('No config specified, use default.'.yellow);
      conf = {};
    }
  }
  if (cmder.server) {
    app = require('./server');
  } else {
    app = require('./client');
  }
  app(conf);
}

==> nobone-sync-0.5.5.tgz: package/main.js <==
var app, cmder, conf, err, file, kit, port, remote;

kit = require('nokit');

kit.require('colors');

cmder = require('commander');

cmder.option('-h, --help', 'Help', function() {
  return cmder.help();
});

cmder.option('-s, --server');

cmder.option('-u, --upload <localFile host[:port]/path/to/dir>', 'Upload file or directory to remote host.');

cmder.option('-p, --password <pwd>', 'Password.');

cmder.option('-a, --algorithm <alg>', 'Algorithm', 'aes128');

cmder.option('-v, --ver', 'Print version', function() {
  console.log((require('./package.json')).version);
  return process.exit();
});

cmder.parse(process.argv);

if (cmder.upload) {
  if (cmder.args.length === 1) {
    conf = {};
    file = cmder.upload;
    file && (conf.localDir = file);
    remote = /([^\/:]+)(:\d+)?\/(.*)/.exec(cmder.args[0]);
    if (!remote || !remote[3]) {
      kit.err('Wrong argument, host[:port]/path/to/file wanted.');
      process.exit(1);
    }
    conf.host = remote[1] || '';
    port = remote[2] || ':8345';
    conf.port = port.slice(1);
    conf.remoteDir = "/" + remote[3];
    conf.password = cmder.password;
    conf.algorithm = cmder.algorithm;
    require('./client')(conf, false);
  } else if (cmder.args.length !== 0) {
    kit.err("Wrong args number, 2 wanted");
  }
} else {
  try {
    require('coffee-script/register');
    conf = require(kit.path.resolve(cmder.args[1] || cmder.args[0]));
  } catch (_error) {
    err = _error;
    if (cmder.args.length > 0) {
      kit.err(err.stack);
      process.exit(1);
    } else {
      kit.log('No config specified, use default.'.yellow);
      conf = {};
    }
  }
  if (cmder.server) {
    app = require('./server');
  } else {
    app = require('./client');
  }
  app(conf);
}
